@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -1584,8 +1583,12 @@ player_done_cb (GooPlayer       *player,
 		GError          *error,
 		GooWindow       *window)
 {
+	gboolean rtl;
+
 	debug (DEBUG_INFO, "DONE [%s]\n", get_action_name (action));
 
+	rtl = gtk_widget_get_direction (GTK_WIDGET (window)) == GTK_TEXT_DIR_RTL;
+
 	switch (action) {
 	case GOO_PLAYER_ACTION_LIST:
 		goo_window_update_album (window);
@@ -1615,14 +1618,14 @@ player_done_cb (GooPlayer       *player,
 	case GOO_PLAYER_ACTION_SEEK_SONG:
 		goo_window_set_current_track (window, goo_player_get_current_track (window->priv->player));
 		goo_window_select_current_track (window);
-		set_current_track_icon (window, GOO_ICON_NAME_PLAY);
+		set_current_track_icon (window, rtl ? GOO_ICON_NAME_PLAY_RTL : GOO_ICON_NAME_PLAY);
 		break;
 
 	case GOO_PLAYER_ACTION_PLAY:
 	case GOO_PLAYER_ACTION_STOP:
 	case GOO_PLAYER_ACTION_MEDIUM_REMOVED:
 		if (action == GOO_PLAYER_ACTION_PLAY) {
-			set_current_track_icon (window, GOO_ICON_NAME_PLAY);
+			set_current_track_icon (window, rtl ? GOO_ICON_NAME_PLAY_RTL : GOO_ICON_NAME_PLAY);
 			window->priv->next_timeout_handle = g_idle_add (next_time_idle, window);
 		}
 		else if (action == GOO_PLAYER_ACTION_STOP)
