@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -261,8 +260,12 @@ system_notify (GooWindow       *window,
 	notify_notification_set_image_from_pixbuf (notification, cover);
 
 	if (notification_supports_actions) {
+		gboolean rtl;
+
 		notify_notification_clear_actions (notification);
 
+		rtl = gtk_widget_get_direction (GTK_WIDGET (window)) == GTK_TEXT_DIR_RTL;
+
 		if (goo_player_get_state (goo_window_get_player (window)) == GOO_PLAYER_STATE_PLAYING)
 			notify_notification_add_action (notification,
 							GOO_ICON_NAME_PAUSE,
@@ -272,14 +275,14 @@ system_notify (GooWindow       *window,
 							NULL);
 		else
 			notify_notification_add_action (notification,
-							GOO_ICON_NAME_PLAY,
+							rtl ? GOO_ICON_NAME_PLAY : GOO_ICON_NAME_PLAY,
 							_("Play"),
 							notify_action_toggle_play_cb,
 							window,
 							NULL);
 
 		notify_notification_add_action (notification,
-						GOO_ICON_NAME_NEXT,
+						rtl ? GOO_ICON_NAME_NEXT_RTL : GOO_ICON_NAME_NEXT,
 						_("Next"),
 						notify_action_next_cb,
 						window,
